@@ -180,11 +180,11 @@ start_shell <- function(master,
 
   if (is.null(gatewayInfo) || gatewayInfo$backendPort == 0)
   {
+    versionSparkHome <- spark_version_from_home(spark_home, default = spark_version)
+
     # read app jar through config, this allows "sparkr-shell" to test sparkr backend
     app_jar <- spark_config_value(config, c("sparklyr.connect.app.jar", "sparklyr.app.jar"), NULL)
     if (is.null(app_jar)) {
-      versionSparkHome <- spark_version_from_home(spark_home, default = spark_version)
-
       app_jar <- spark_default_app_jar(versionSparkHome)
       if (typeof(app_jar) != "character" || nchar(app_jar) == 0) {
         stop("sparklyr does not support Spark version: ", versionSparkHome)
@@ -247,6 +247,7 @@ start_shell <- function(master,
     all_jars <- c(jars, extensions$jars)
     jars <- if (length(all_jars) > 0) normalizePath(unlist(unique(all_jars))) else list()
     packages <- unique(c(packages, extensions$packages))
+    repositories <- extensions$repositories
 
     # include embedded jars, if needed
     csv_config_value <- spark_config_value(config, c("sparklyr.connect.csv.embedded", "sparklyr.csv.embedded"))
@@ -280,6 +281,11 @@ start_shell <- function(master,
       shell_args <- c(shell_args, "--packages", paste(shQuote(packages, type = shQuoteType), collapse=","))
     }
 
+    # add repositories to arguments
+    if (length(repositories) > 0) {
+      shell_args <- c(shell_args, "--repositories", paste(repositories, collapse=","))
+    }
+
     # add environment parameters to arguments
     shell_env_args <- Sys.getenv("sparklyr.shell.args")
     if (nchar(shell_env_args) > 0) {
